searchData={"content_type":"text/markdown","items":[{"doc":"Reference this repository on your `mix.exs` file to start using.\n\n```elixir\ndef deps do\n  [\n    {:daisy_ui_components, \"~> 0.1\"}\n  ]\nend\n```\n\nAdd through `npm` the daisy UI package inside your phoenix application:\n\n```\ncd assets\nnpm i -D daisyui@latest\n```\n\nOn `tailwind.config.js` include Live DaisyUI Components under the content list and reference under plugins\n\n```javascript\nmodule.exports = {\n  content: [\n    //...\n    \"../deps/daisy_ui_components/**/*.*ex\" // <- reference DaisyUIComponents as content path\n  ],\n  //...\n  plugins: [\n    //...\n    require(\"daisyui\")  <- // add daisyUI plugin\n    //...\n  ]\n}\n```\n\nAdd error translation function to your app's config.exs file. This function is used to translate ecto changeset errors\n\n```elixir\nconfig :daisy_ui_components, translate_function: &MyAppWeb.CoreComponents.translate_error/1\n```\n\nAnd now this library is ready. To have the components available under liveview, import the components on the web folder\n\n```elixir\ndefp html_helpers do\n  quote do\n    use DaisyUIComponents\n    # HTML escaping functionality\n    import Phoenix.HTML\n    # Core UI components from Live DaisyUI\n    import DaisyUIComponents.CoreComponents\n\n    # import YourProjectWeb.CoreComponents\n    # Importing CoreComponents from your project is no longer necessary since\n    # DaisyUIComponents.CoreComponents offers a drop in replacement\n    # If you still want to use your own core components, remember to delete the default components generated from phoenix in this file\n    # ...\n  end\nend\n```\n\nCheck the [Core Components](./lib/daisy_ui_components/core_components.ex) implementation for replacing the default phoenix core components. The components have the same logic from Phoenix default generator, but now using DaisyUI styles.","ref":"DaisyUIComponents.html","title":"DaisyUIComponents","type":"module"},{"doc":"List of available components.\n\n- [Alert](https://daisyui.com/components/alert) ✅\n- [Artboard](https://daisyui.com/components/artboard) ❌\n- [Avatar](https://daisyui.com/components/avatar) ✅\n- [Badge](https://daisyui.com/components/badge) ✅\n- [Bottom navigation](https://daisyui.com/components/botton-navigation) ❌\n- [Breadcrumbs](https://daisyui.com/components/breadcrumbs) ❌\n- [Button group](https://daisyui.com/components/button-group) ✅ ❌\n- [Button](https://daisyui.com/components/button) ✅ ❌\n- [Card](https://daisyui.com/components/card) ✅\n- [Carousel](https://daisyui.com/components/carousel) ❌\n- [Chat bubble](https://daisyui.com/components/chat) ❌\n- [Checkbox](https://daisyui.com/components/checkbox) ✅\n- [Collapse](https://daisyui.com/components/collapse) ❌\n- [Countdown](https://daisyui.com/components/countdown) ❌\n- [Divider](https://daisyui.com/components/divider) ❌\n- [Drawer](https://daisyui.com/components/drawer) ❌\n- [Dropdown](https://daisyui.com/components/dropdown) ❌\n- [File input](https://daisyui.com/components/file-input) ❌\n- [Footer](https://daisyui.com/components/footer) ❌\n- [Join](https://daisyui.com/components/join) ✅\n- [Hero](https://daisyui.com/components/hero) ❌\n- [Indicator](https://daisyui.com/components/indicator) ❌\n- [Input group](https://daisyui.com/components/input-group) ❌\n- [Text Input](https://daisyui.com/components/input) ✅\n- [Kbd](https://daisyui.com/components/kbd) ❌\n- [Link](https://daisyui.com/components/link) ❌\n- [Mask](https://daisyui.com/components/mask) ❌\n- [Menu](https://daisyui.com/components/menu) ❌\n- [Code mockup](https://daisyui.com/components/mockup-code) ❌\n- [Phone mockup](https://daisyui.com/components/mockup-phone) ❌\n- [Window mockup](https://daisyui.com/components/mockup-window) ❌\n- [Modal](https://daisyui.com/components/modal) ✅\n- [Navbar](https://daisyui.com/components/navbar) ✅\n- [Pagination](https://daisyui.com/components/pagination) ✅\n- [Progress](https://daisyui.com/components/progress) ❌\n- [Radial progress](https://daisyui.com/components/radial-progress) ❌\n- [Radio](https://daisyui.com/components/radio) ❌\n- [Range slider](https://daisyui.com/components/range) ❌\n- [Rating](https://daisyui.com/components/rating) ❌\n- [Select](https://daisyui.com/components/select) ✅\n- [Stack](https://daisyui.com/components/stack) ❌\n- [Stat](https://daisyui.com/components/stat) ✅\n- [Steps](https://daisyui.com/components/steps) ❌\n- [Swap](https://daisyui.com/components/swap) ❌\n- [Tabs](https://daisyui.com/components/tab) ❌\n- [Table](https://daisyui.com/components/table) ✅\n- [Textarea](https://daisyui.com/components/textarea) ✅\n- [Toast](https://daisyui.com/components/toast) ❌\n- [Toggle](https://daisyui.com/components/toggle) ❌\n- [Tooltip](https://daisyui.com/components/tooltip) ✅\n\n✅: Implemented\n\n❌: To be implemented","ref":"DaisyUIComponents.html#module-components","title":"Components - DaisyUIComponents","type":"module"},{"doc":"Alert component\n\nhttps://daisyui.com/components/alert","ref":"DaisyUIComponents.Alert.html","title":"DaisyUIComponents.Alert","type":"module"},{"doc":"","ref":"DaisyUIComponents.Alert.html#alert/1","title":"DaisyUIComponents.Alert.alert/1","type":"function"},{"doc":"* `class` (`:any`) - Defaults to `nil`.\n* `color` (`:string`) - Must be one of `\"info\"`, `\"success\"`, `\"warning\"`, or `\"error\"`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Alert.html#alert/1-attributes","title":"Attributes - DaisyUIComponents.Alert.alert/1","type":"function"},{"doc":"* `inner_block`","ref":"DaisyUIComponents.Alert.html#alert/1-slots","title":"Slots - DaisyUIComponents.Alert.alert/1","type":"function"},{"doc":"Renders flash notices.","ref":"DaisyUIComponents.Alert.html#flash/1","title":"DaisyUIComponents.Alert.flash/1","type":"function"},{"doc":"<.flash kind={:info} flash={@flash} />\n    <.flash kind={:info} phx-mounted={show(\"#flash\")}>Welcome Back!</.flash>","ref":"DaisyUIComponents.Alert.html#flash/1-examples","title":"Examples - DaisyUIComponents.Alert.flash/1","type":"function"},{"doc":"* `id` (`:string`) - the optional id of flash container.\n* `flash` (`:map`) - the map of flash messages to display. Defaults to `%{}`.\n* `title` (`:string`) - Defaults to `nil`.\n* `kind` (`:atom`) - used for styling and flash lookup.Must be one of `:info`, or `:error`.\n* `class` (`:string`) - Defaults to `nil`.\n* `direction` (`:atom`) - Defaults to `:top_right`.\n* Global attributes are accepted. the arbitrary HTML attributes to add to the flash container.","ref":"DaisyUIComponents.Alert.html#flash/1-attributes","title":"Attributes - DaisyUIComponents.Alert.flash/1","type":"function"},{"doc":"* `inner_block` - the optional inner block that renders the flash message.","ref":"DaisyUIComponents.Alert.html#flash/1-slots","title":"Slots - DaisyUIComponents.Alert.flash/1","type":"function"},{"doc":"Shows the flash group with standard titles and content.","ref":"DaisyUIComponents.Alert.html#flash_group/1","title":"DaisyUIComponents.Alert.flash_group/1","type":"function"},{"doc":"<.flash_group flash={@flash} />","ref":"DaisyUIComponents.Alert.html#flash_group/1-examples","title":"Examples - DaisyUIComponents.Alert.flash_group/1","type":"function"},{"doc":"* `flash` (`:map`) (required) - the map of flash messages.\n* `id` (`:string`) - the optional id of flash container. Defaults to `\"flash-group\"`.\n* `direction` (`:atom`) - Defaults to `:top_right`.","ref":"DaisyUIComponents.Alert.html#flash_group/1-attributes","title":"Attributes - DaisyUIComponents.Alert.flash_group/1","type":"function"},{"doc":"Avatar component\n\nhttps://daisyui.com/components/avatar","ref":"DaisyUIComponents.Avatar.html","title":"DaisyUIComponents.Avatar","type":"module"},{"doc":"","ref":"DaisyUIComponents.Avatar.html#avatar/1","title":"DaisyUIComponents.Avatar.avatar/1","type":"function"},{"doc":"* `online` (`:boolean`) - Defaults to `false`.\n* `offline` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Avatar.html#avatar/1-attributes","title":"Attributes - DaisyUIComponents.Avatar.avatar/1","type":"function"},{"doc":"* `inner_block`","ref":"DaisyUIComponents.Avatar.html#avatar/1-slots","title":"Slots - DaisyUIComponents.Avatar.avatar/1","type":"function"},{"doc":"","ref":"DaisyUIComponents.Avatar.html#avatar_group/1","title":"DaisyUIComponents.Avatar.avatar_group/1","type":"function"},{"doc":"* Global attributes are accepted.","ref":"DaisyUIComponents.Avatar.html#avatar_group/1-attributes","title":"Attributes - DaisyUIComponents.Avatar.avatar_group/1","type":"function"},{"doc":"* `inner_block`","ref":"DaisyUIComponents.Avatar.html#avatar_group/1-slots","title":"Slots - DaisyUIComponents.Avatar.avatar_group/1","type":"function"},{"doc":"Badge component\n\nhttps://daisyui.com/components/badge/","ref":"DaisyUIComponents.Badge.html","title":"DaisyUIComponents.Badge","type":"module"},{"doc":"Renders a badge.","ref":"DaisyUIComponents.Badge.html#badge/1","title":"DaisyUIComponents.Badge.badge/1","type":"function"},{"doc":"<.badge>Default</.badge>\n    <.badge primary class=\"gap-2\">Primary</.badge>","ref":"DaisyUIComponents.Badge.html#badge/1-examples","title":"Examples - DaisyUIComponents.Badge.badge/1","type":"function"},{"doc":"* `class` (`:string`) - Defaults to `nil`.\n* `color` (`:string`) - Must be one of `\"primary\"`, `\"secondary\"`, `\"accent\"`, `\"info\"`, `\"success\"`, `\"warning\"`, `\"error\"`, or `\"neutral\"`.\n* `ghost` (`:boolean`) - Defaults to `false`.\n* `outline` (`:boolean`) - Defaults to `false`.\n* `size` (`:string`) - Must be one of `\"xs\"`, `\"sm\"`, `\"md\"`, or `\"lg\"`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Badge.html#badge/1-attributes","title":"Attributes - DaisyUIComponents.Badge.badge/1","type":"function"},{"doc":"* `inner_block`","ref":"DaisyUIComponents.Badge.html#badge/1-slots","title":"Slots - DaisyUIComponents.Badge.badge/1","type":"function"},{"doc":"Button component\n\nhttps://daisyui.com/components/button/","ref":"DaisyUIComponents.Button.html","title":"DaisyUIComponents.Button","type":"module"},{"doc":"Renders a button.","ref":"DaisyUIComponents.Button.html#button/1","title":"DaisyUIComponents.Button.button/1","type":"function"},{"doc":"<.button>Send!</.button>\n    <.button phx-click=\"go\" class=\"ml-2\">Send!</.button>","ref":"DaisyUIComponents.Button.html#button/1-examples","title":"Examples - DaisyUIComponents.Button.button/1","type":"function"},{"doc":"* `class` (`:string`) - Defaults to `nil`.\n* `color` (`:string`) - Must be one of `\"primary\"`, `\"secondary\"`, `\"accent\"`, `\"info\"`, `\"success\"`, `\"warning\"`, `\"error\"`, or `\"neutral\"`.\n* `ghost` (`:boolean`) - Defaults to `false`.\n* `link` (`:boolean`) - Defaults to `false`.\n* `outline` (`:boolean`) - Defaults to `false`.\n* `active` (`:boolean`) - Defaults to `false`.\n* `disabled` (`:boolean`) - Defaults to `false`.\n* `glass` (`:boolean`) - Defaults to `false`.\n* `loading` (`:boolean`) - Defaults to `false`.\n* `no_animation` (`:boolean`) - Defaults to `false`.\n* `size` (`:string`) - Must be one of `\"xs\"`, `\"sm\"`, `\"md\"`, or `\"lg\"`.\n* `wide` (`:boolean`) - Defaults to `false`.\n* `block` (`:boolean`) - Defaults to `false`.\n* `shape` (`:string`) - Must be one of `\"circle\"`, or `\"square\"`.\n* Global attributes are accepted. Supports all globals plus: `[\"form\", \"name\", \"value\"]`.","ref":"DaisyUIComponents.Button.html#button/1-attributes","title":"Attributes - DaisyUIComponents.Button.button/1","type":"function"},{"doc":"* `inner_block` (required)","ref":"DaisyUIComponents.Button.html#button/1-slots","title":"Slots - DaisyUIComponents.Button.button/1","type":"function"},{"doc":"Button Group component\n\nhttps://daisyui.com/components/button-group/","ref":"DaisyUIComponents.ButtonGroup.html","title":"DaisyUIComponents.ButtonGroup","type":"module"},{"doc":"Renders a button group.","ref":"DaisyUIComponents.ButtonGroup.html#button_group/1","title":"DaisyUIComponents.ButtonGroup.button_group/1","type":"function"},{"doc":"<.button_group>\n      <.button active>Button</.button>\n      <.button>Button</.button>\n      <.button>Button</.button>\n    </.button_group>","ref":"DaisyUIComponents.ButtonGroup.html#button_group/1-examples","title":"Examples - DaisyUIComponents.ButtonGroup.button_group/1","type":"function"},{"doc":"* `class` (`:string`) - Defaults to `nil`.\n* `direction` (`:string`) - Must be one of `\"horizontal\"`, or `\"vertical\"`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.ButtonGroup.html#button_group/1-attributes","title":"Attributes - DaisyUIComponents.ButtonGroup.button_group/1","type":"function"},{"doc":"* `inner_block` (required)","ref":"DaisyUIComponents.ButtonGroup.html#button_group/1-slots","title":"Slots - DaisyUIComponents.ButtonGroup.button_group/1","type":"function"},{"doc":"Card component\n\nhttps://daisyui.com/components/card/","ref":"DaisyUIComponents.Card.html","title":"DaisyUIComponents.Card","type":"module"},{"doc":"","ref":"DaisyUIComponents.Card.html#card/1","title":"DaisyUIComponents.Card.card/1","type":"function"},{"doc":"* `bordered` (`:boolean`) - Defaults to `false`.\n* `side` (`:boolean`) - Defaults to `false`.\n* `padding` (`:string`) - Must be one of `\"normal\"`, or `\"compact\"`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Card.html#card/1-attributes","title":"Attributes - DaisyUIComponents.Card.card/1","type":"function"},{"doc":"* `inner_block`","ref":"DaisyUIComponents.Card.html#card/1-slots","title":"Slots - DaisyUIComponents.Card.card/1","type":"function"},{"doc":"","ref":"DaisyUIComponents.Card.html#card_actions/1","title":"DaisyUIComponents.Card.card_actions/1","type":"function"},{"doc":"* Global attributes are accepted.","ref":"DaisyUIComponents.Card.html#card_actions/1-attributes","title":"Attributes - DaisyUIComponents.Card.card_actions/1","type":"function"},{"doc":"* `inner_block`","ref":"DaisyUIComponents.Card.html#card_actions/1-slots","title":"Slots - DaisyUIComponents.Card.card_actions/1","type":"function"},{"doc":"","ref":"DaisyUIComponents.Card.html#card_body/1","title":"DaisyUIComponents.Card.card_body/1","type":"function"},{"doc":"* Global attributes are accepted.","ref":"DaisyUIComponents.Card.html#card_body/1-attributes","title":"Attributes - DaisyUIComponents.Card.card_body/1","type":"function"},{"doc":"* `inner_block`","ref":"DaisyUIComponents.Card.html#card_body/1-slots","title":"Slots - DaisyUIComponents.Card.card_body/1","type":"function"},{"doc":"","ref":"DaisyUIComponents.Card.html#card_title/1","title":"DaisyUIComponents.Card.card_title/1","type":"function"},{"doc":"* `label` (`:string`) - Defaults to `nil`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Card.html#card_title/1-attributes","title":"Attributes - DaisyUIComponents.Card.card_title/1","type":"function"},{"doc":"* `inner_block`","ref":"DaisyUIComponents.Card.html#card_title/1-slots","title":"Slots - DaisyUIComponents.Card.card_title/1","type":"function"},{"doc":"Checkbox component\n\nhttps://daisyui.com/components/checkbox","ref":"DaisyUIComponents.Checkbox.html","title":"DaisyUIComponents.Checkbox","type":"module"},{"doc":"","ref":"DaisyUIComponents.Checkbox.html#checkbox/1","title":"DaisyUIComponents.Checkbox.checkbox/1","type":"function"},{"doc":"* `checked` (`:boolean`) - the checked flag for checkbox inputs. Defaults to `nil`.\n* `value` (`:any`) - Defaults to `nil`.\n* `color` (`:string`) - Must be one of `\"primary\"`, `\"secondary\"`, `\"accent\"`, `\"info\"`, `\"success\"`, `\"warning\"`, or `\"error\"`.\n* `size` (`:string`) - Must be one of `\"xs\"`, `\"sm\"`, `\"md\"`, or `\"lg\"`.\n* Global attributes are accepted. Supports all globals plus: `[\"name\"]`.","ref":"DaisyUIComponents.Checkbox.html#checkbox/1-attributes","title":"Attributes - DaisyUIComponents.Checkbox.checkbox/1","type":"function"},{"doc":"UI components from [Phoenix Core Components](https://github.com/phoenixframework/phoenix/blob/main/installer/templates/phx_web/components/core_components.ex).\n\nThe components were modified to fit DaisyUI components","ref":"DaisyUIComponents.CoreComponents.html","title":"DaisyUIComponents.CoreComponents","type":"module"},{"doc":"Renders a back navigation link.","ref":"DaisyUIComponents.CoreComponents.html#back/1","title":"DaisyUIComponents.CoreComponents.back/1","type":"function"},{"doc":"<.back navigate={~p\"/posts\"}>Back to posts</.back>","ref":"DaisyUIComponents.CoreComponents.html#back/1-examples","title":"Examples - DaisyUIComponents.CoreComponents.back/1","type":"function"},{"doc":"* `navigate` (`:any`) (required)","ref":"DaisyUIComponents.CoreComponents.html#back/1-attributes","title":"Attributes - DaisyUIComponents.CoreComponents.back/1","type":"function"},{"doc":"* `inner_block` (required)","ref":"DaisyUIComponents.CoreComponents.html#back/1-slots","title":"Slots - DaisyUIComponents.CoreComponents.back/1","type":"function"},{"doc":"Renders a header with title.","ref":"DaisyUIComponents.CoreComponents.html#header/1","title":"DaisyUIComponents.CoreComponents.header/1","type":"function"},{"doc":"* `class` (`:string`) - Defaults to `nil`.","ref":"DaisyUIComponents.CoreComponents.html#header/1-attributes","title":"Attributes - DaisyUIComponents.CoreComponents.header/1","type":"function"},{"doc":"* `inner_block` (required)\n* `subtitle`\n* `actions`","ref":"DaisyUIComponents.CoreComponents.html#header/1-slots","title":"Slots - DaisyUIComponents.CoreComponents.header/1","type":"function"},{"doc":"Renders a data list.","ref":"DaisyUIComponents.CoreComponents.html#list/1","title":"DaisyUIComponents.CoreComponents.list/1","type":"function"},{"doc":"<.list>\n      <:item title=\"Title\"><%= @post.title %></:item>\n      <:item title=\"Views\"><%= @post.views %></:item>\n    </.list>","ref":"DaisyUIComponents.CoreComponents.html#list/1-examples","title":"Examples - DaisyUIComponents.CoreComponents.list/1","type":"function"},{"doc":"* `item` (required) - Accepts attributes:\n\n  * `title` (`:string`) (required)","ref":"DaisyUIComponents.CoreComponents.html#list/1-slots","title":"Slots - DaisyUIComponents.CoreComponents.list/1","type":"function"},{"doc":"Renders a simple form.","ref":"DaisyUIComponents.CoreComponents.html#simple_form/1","title":"DaisyUIComponents.CoreComponents.simple_form/1","type":"function"},{"doc":"<.simple_form for={@form} phx-change=\"validate\" phx-submit=\"save\">\n      <.input field={@form[:email]} label=\"Email\"/>\n      <.input field={@form[:username]} label=\"Username\" />\n      <:actions>\n        <.button>Save</.button>\n      </:actions>\n    </.simple_form>","ref":"DaisyUIComponents.CoreComponents.html#simple_form/1-examples","title":"Examples - DaisyUIComponents.CoreComponents.simple_form/1","type":"function"},{"doc":"* `for` (`:any`) (required) - the datastructure for the form.\n* `as` (`:any`) - the server side parameter to collect all input under. Defaults to `nil`.\n* Global attributes are accepted. the arbitrary HTML attributes to apply to the form tag. Supports all globals plus: `[\"autocomplete\", \"name\", \"rel\", \"action\", \"enctype\", \"method\", \"novalidate\", \"target\"]`.","ref":"DaisyUIComponents.CoreComponents.html#simple_form/1-attributes","title":"Attributes - DaisyUIComponents.CoreComponents.simple_form/1","type":"function"},{"doc":"* `inner_block` (required)\n* `actions` - the slot for form actions, such as a submit button.","ref":"DaisyUIComponents.CoreComponents.html#simple_form/1-slots","title":"Slots - DaisyUIComponents.CoreComponents.simple_form/1","type":"function"},{"doc":"Renders a table with generic styling.","ref":"DaisyUIComponents.CoreComponents.html#simple_table/1","title":"DaisyUIComponents.CoreComponents.simple_table/1","type":"function"},{"doc":"<.simple_table id=\"users\" rows={@users}>\n      <:col :let={user} label=\"id\"><%= user.id %></:col>\n      <:col :let={user} label=\"username\"><%= user.username %></:col>\n    </.simple_table>","ref":"DaisyUIComponents.CoreComponents.html#simple_table/1-examples","title":"Examples - DaisyUIComponents.CoreComponents.simple_table/1","type":"function"},{"doc":"* `id` (`:string`) (required)\n* `rows` (`:list`) (required)\n* `row_id` (`:any`) - the function for generating the row id. Defaults to `nil`.\n* `row_click` (`:any`) - the function for handling phx-click on each row. Defaults to `nil`.\n* `row_item` (`:any`) - the function for mapping each row before calling the :col and :action slots. Defaults to `&Function.identity/1`.","ref":"DaisyUIComponents.CoreComponents.html#simple_table/1-attributes","title":"Attributes - DaisyUIComponents.CoreComponents.simple_table/1","type":"function"},{"doc":"* `col` (required) - Accepts attributes:\n\n  * `label` (`:string`)\n* `action` - the slot for showing user actions in the last table column.","ref":"DaisyUIComponents.CoreComponents.html#simple_table/1-slots","title":"Slots - DaisyUIComponents.CoreComponents.simple_table/1","type":"function"},{"doc":"Drawer component\n\nhttps://daisyui.com/components/drawer","ref":"DaisyUIComponents.Drawer.html","title":"DaisyUIComponents.Drawer","type":"module"},{"doc":"","ref":"DaisyUIComponents.Drawer.html#drawer/1","title":"DaisyUIComponents.Drawer.drawer/1","type":"function"},{"doc":"* `id` (`:string`) (required)\n* `class` (`:any`) - Defaults to `nil`.","ref":"DaisyUIComponents.Drawer.html#drawer/1-attributes","title":"Attributes - DaisyUIComponents.Drawer.drawer/1","type":"function"},{"doc":"* `page_content`\n* `inner_block` (required)","ref":"DaisyUIComponents.Drawer.html#drawer/1-slots","title":"Slots - DaisyUIComponents.Drawer.drawer/1","type":"function"},{"doc":"","ref":"DaisyUIComponents.Drawer.html#drawer_side/1","title":"DaisyUIComponents.Drawer.drawer_side/1","type":"function"},{"doc":"* `drawer_id` (`:string`) (required)\n* `class` (`:any`) - Defaults to `nil`.","ref":"DaisyUIComponents.Drawer.html#drawer_side/1-attributes","title":"Attributes - DaisyUIComponents.Drawer.drawer_side/1","type":"function"},{"doc":"* `inner_block` (required)","ref":"DaisyUIComponents.Drawer.html#drawer_side/1-slots","title":"Slots - DaisyUIComponents.Drawer.drawer_side/1","type":"function"},{"doc":"Form component helpers","ref":"DaisyUIComponents.Form.html","title":"DaisyUIComponents.Form","type":"module"},{"doc":"Generates a generic error message.","ref":"DaisyUIComponents.Form.html#error/1","title":"DaisyUIComponents.Form.error/1","type":"function"},{"doc":"* `show` (`:boolean`) - Defaults to `false`.","ref":"DaisyUIComponents.Form.html#error/1-attributes","title":"Attributes - DaisyUIComponents.Form.error/1","type":"function"},{"doc":"* `inner_block` (required)","ref":"DaisyUIComponents.Form.html#error/1-slots","title":"Slots - DaisyUIComponents.Form.error/1","type":"function"},{"doc":"Renders an input with label and error messages.\n\nA `%Phoenix.HTML.Form{}` and field name may be passed to the input\nto build input names and error messages, or all the attributes and\nerrors may be passed explicitly.","ref":"DaisyUIComponents.Form.html#form_input/1","title":"DaisyUIComponents.Form.form_input/1","type":"function"},{"doc":"<.input field={@form[:email]} type=\"email\" />\n    <.input name=\"my-input\" errors={[\"oh no!\"]} />","ref":"DaisyUIComponents.Form.html#form_input/1-examples","title":"Examples - DaisyUIComponents.Form.form_input/1","type":"function"},{"doc":"* `id` (`:any`) - Defaults to `nil`.\n* `name` (`:any`)\n* `label` (`:string`) - Defaults to `nil`.\n* `value` (`:any`)\n* `type` (`:string`) - Defaults to `\"text\"`.\n* `field` (`Phoenix.HTML.FormField`) - a form field struct retrieved from the form, for example: @form[:email].\n* `class` (`:string`) - Defaults to `nil`.\n* `bordered` (`:boolean`) - Defaults to `true`.\n* `errors` (`:list`) - Defaults to `[]`.\n* `checked` (`:boolean`) - the checked flag for checkbox inputs.\n* `prompt` (`:string`) - the prompt for select inputs. Defaults to `nil`.\n* `options` (`:list`) - the options to pass to Phoenix.HTML.Form.options_for_select/2.\n* `multiple` (`:boolean`) - the multiple flag for select inputs. Defaults to `false`.\n* Global attributes are accepted. Supports all globals plus: `[\"autocomplete\", \"cols\", \"disabled\", \"form\", \"list\", \"max\", \"maxlength\", \"min\", \"minlength\", \"pattern\", \"placeholder\", \"readonly\", \"required\", \"rows\", \"size\", \"step\"]`.","ref":"DaisyUIComponents.Form.html#form_input/1-attributes","title":"Attributes - DaisyUIComponents.Form.form_input/1","type":"function"},{"doc":"* `inner_block`","ref":"DaisyUIComponents.Form.html#form_input/1-slots","title":"Slots - DaisyUIComponents.Form.form_input/1","type":"function"},{"doc":"Renders a label.","ref":"DaisyUIComponents.Form.html#label/1","title":"DaisyUIComponents.Form.label/1","type":"function"},{"doc":"* `class` (`:any`) - Defaults to `nil`.\n* `for` (`:string`) - Defaults to `nil`.\n* `type` (`:string`) - Defaults to `\"label\"`.\n* `label` (`:string`) - Defaults to `nil`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Form.html#label/1-attributes","title":"Attributes - DaisyUIComponents.Form.label/1","type":"function"},{"doc":"* `inner_block`","ref":"DaisyUIComponents.Form.html#label/1-slots","title":"Slots - DaisyUIComponents.Form.label/1","type":"function"},{"doc":"Renders hero icons\nCode extracted from [Phoenix Core Components](https://github.com/phoenixframework/phoenix/blob/main/installer/templates/phx_web/components/core_components.ex).","ref":"DaisyUIComponents.Icon.html","title":"DaisyUIComponents.Icon","type":"module"},{"doc":"Renders a [Hero Icon](https://heroicons.com).\n\nHero icons come in three styles – outline, solid, and mini.\nBy default, the outline style is used, but solid and mini may\nbe applied by using the `-solid` and `-mini` suffix.\n\nYou can customize the size and colors of the icons by setting\nwidth, height, and background color classes.\n\nIcons are extracted from your `assets/vendor/heroicons` directory and bundled\nwithin your compiled app.css by the plugin in your `assets/tailwind.config.js`.","ref":"DaisyUIComponents.Icon.html#icon/1","title":"DaisyUIComponents.Icon.icon/1","type":"function"},{"doc":"<.icon name=\"hero-x-mark-solid\" />\n    <.icon name=\"hero-arrow-path\" class=\"ml-1 w-3 h-3 animate-spin\" />","ref":"DaisyUIComponents.Icon.html#icon/1-examples","title":"Examples - DaisyUIComponents.Icon.icon/1","type":"function"},{"doc":"* `id` (`:any`) - Defaults to `nil`.\n* `name` (`:string`) (required)\n* `class` (`:string`) - Defaults to `nil`.","ref":"DaisyUIComponents.Icon.html#icon/1-attributes","title":"Attributes - DaisyUIComponents.Icon.icon/1","type":"function"},{"doc":"Generic Input component","ref":"DaisyUIComponents.Input.html","title":"DaisyUIComponents.Input","type":"module"},{"doc":"Renders a generic input based on type.","ref":"DaisyUIComponents.Input.html#input/1","title":"DaisyUIComponents.Input.input/1","type":"function"},{"doc":"<.input type=\"email\" />\n    <.input name=\"my-input\" type=\"checkbox\" value=\"false\" />","ref":"DaisyUIComponents.Input.html#input/1-examples","title":"Examples - DaisyUIComponents.Input.input/1","type":"function"},{"doc":"* `id` (`:any`) - Defaults to `nil`.\n* `type` (`:string`) - Defaults to `\"text\"`.\n* `bordered` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. Supports all globals plus: `[\"name\", \"value\", \"checked\", \"prompt\", \"options\", \"multiple\", \"autocomplete\", \"cols\", \"disabled\", \"form\", \"list\", \"max\", \"maxlength\", \"min\", \"minlength\", \"pattern\", \"placeholder\", \"readonly\", \"required\", \"rows\", \"size\", \"step\"]`.","ref":"DaisyUIComponents.Input.html#input/1-attributes","title":"Attributes - DaisyUIComponents.Input.input/1","type":"function"},{"doc":"* `inner_block`","ref":"DaisyUIComponents.Input.html#input/1-slots","title":"Slots - DaisyUIComponents.Input.input/1","type":"function"},{"doc":"Button Group component\n\nhttps://daisyui.com/components/join/","ref":"DaisyUIComponents.Join.html","title":"DaisyUIComponents.Join","type":"module"},{"doc":"Join elements","ref":"DaisyUIComponents.Join.html#join/1","title":"DaisyUIComponents.Join.join/1","type":"function"},{"doc":"<.join>\n      <.button class=\"join-item\" active>Button</.button>\n      <.button class=\"join-item\">Button</.button>\n      <.button class=\"join-item\">Button</.button>\n    </.join>","ref":"DaisyUIComponents.Join.html#join/1-examples","title":"Examples - DaisyUIComponents.Join.join/1","type":"function"},{"doc":"* `class` (`:string`) - Defaults to `nil`.\n* `direction` (`:string`) - Must be one of `\"horizontal\"`, or `\"vertical\"`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Join.html#join/1-attributes","title":"Attributes - DaisyUIComponents.Join.join/1","type":"function"},{"doc":"* `inner_block` (required)","ref":"DaisyUIComponents.Join.html#join/1-slots","title":"Slots - DaisyUIComponents.Join.join/1","type":"function"},{"doc":"Modal component\n\nhttps://daisyui.com/components/modal/","ref":"DaisyUIComponents.Modal.html","title":"DaisyUIComponents.Modal","type":"module"},{"doc":"Renders a dialog modal.","ref":"DaisyUIComponents.Modal.html#dialog_modal/1","title":"DaisyUIComponents.Modal.dialog_modal/1","type":"function"},{"doc":"<.dialog_modal id=\"confirm-modal\">\n      <.modal_box>\n        This is a modal\n      </.modal_box>\n    </.dialog_modal>\n\nJS commands may be passed to the `:on_cancel` to configure\nthe closing/cancel event, for example:\n\n    <.modal id=\"confirm\" on_cancel={JS.navigate(~p\"/posts\")}>\n      <.modal_box>\n        This is another modal\n      </.modal_box>\n    </.modal>\n\ndialog with actions:\n\n    <.dialog_modal id=\"confirm\">\n      <.modal_box>\n        Modal to confirm\n      </.modal_box>\n      <:actions>\n        <.button>Confirm</.button>\n      <:actions>\n    </.dialog_modal>","ref":"DaisyUIComponents.Modal.html#dialog_modal/1-examples","title":"Examples - DaisyUIComponents.Modal.dialog_modal/1","type":"function"},{"doc":"* `id` (`:string`) (required)\n* `class` (`:string`) - Defaults to `nil`.\n* `open` (`:boolean`) - Defaults to `false`.\n* `on_cancel` (`Phoenix.LiveView.JS`) - Defaults to `%Phoenix.LiveView.JS{ops: []}`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Modal.html#dialog_modal/1-attributes","title":"Attributes - DaisyUIComponents.Modal.dialog_modal/1","type":"function"},{"doc":"* `inner_block`","ref":"DaisyUIComponents.Modal.html#dialog_modal/1-slots","title":"Slots - DaisyUIComponents.Modal.dialog_modal/1","type":"function"},{"doc":"","ref":"DaisyUIComponents.Modal.html#hide_modal/2","title":"DaisyUIComponents.Modal.hide_modal/2","type":"function"},{"doc":"Renders a modal.","ref":"DaisyUIComponents.Modal.html#modal/1","title":"DaisyUIComponents.Modal.modal/1","type":"function"},{"doc":"<.modal id=\"confirm-modal\">\n      This is a modal.\n    </.modal>\n\nJS commands may be passed to the `:on_cancel` to configure\nthe closing/cancel event, for example:\n\n    <.modal id=\"confirm\" on_cancel={JS.navigate(~p\"/posts\")}>\n      This is another modal.\n    </.modal>\n\nModal with actions:\n\n    <.modal id=\"confirm\">\n      Modal to confirm\n      <:actions>\n        <.button>Confirm</.button>\n      <:actions>\n    </.modal>","ref":"DaisyUIComponents.Modal.html#modal/1-examples","title":"Examples - DaisyUIComponents.Modal.modal/1","type":"function"},{"doc":"* `id` (`:string`) (required)\n* `open` (`:boolean`) - Defaults to `false`.\n* `on_cancel` (`Phoenix.LiveView.JS`) - Defaults to `%Phoenix.LiveView.JS{ops: []}`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Modal.html#modal/1-attributes","title":"Attributes - DaisyUIComponents.Modal.modal/1","type":"function"},{"doc":"* `actions` - the slot for showing modal actions.\n* `inner_block`","ref":"DaisyUIComponents.Modal.html#modal/1-slots","title":"Slots - DaisyUIComponents.Modal.modal/1","type":"function"},{"doc":"","ref":"DaisyUIComponents.Modal.html#modal_action/1","title":"DaisyUIComponents.Modal.modal_action/1","type":"function"},{"doc":"* `class` (`:string`) - Defaults to `nil`.","ref":"DaisyUIComponents.Modal.html#modal_action/1-attributes","title":"Attributes - DaisyUIComponents.Modal.modal_action/1","type":"function"},{"doc":"* `inner_block`","ref":"DaisyUIComponents.Modal.html#modal_action/1-slots","title":"Slots - DaisyUIComponents.Modal.modal_action/1","type":"function"},{"doc":"","ref":"DaisyUIComponents.Modal.html#modal_box/1","title":"DaisyUIComponents.Modal.modal_box/1","type":"function"},{"doc":"* `modal_id` (`:string`) (required)\n* `class` (`:string`) - Defaults to `nil`.\n* `closable` (`:boolean`) - Defaults to `true`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Modal.html#modal_box/1-attributes","title":"Attributes - DaisyUIComponents.Modal.modal_box/1","type":"function"},{"doc":"* `inner_block`\n* `actions` - the slot for showing modal actions.","ref":"DaisyUIComponents.Modal.html#modal_box/1-slots","title":"Slots - DaisyUIComponents.Modal.modal_box/1","type":"function"},{"doc":"","ref":"DaisyUIComponents.Modal.html#show_modal/2","title":"DaisyUIComponents.Modal.show_modal/2","type":"function"},{"doc":"Navbar component\n\nhttps://daisyui.com/components/navbar/","ref":"DaisyUIComponents.Navbar.html","title":"DaisyUIComponents.Navbar","type":"module"},{"doc":"","ref":"DaisyUIComponents.Navbar.html#navbar/1","title":"DaisyUIComponents.Navbar.navbar/1","type":"function"},{"doc":"* Global attributes are accepted.","ref":"DaisyUIComponents.Navbar.html#navbar/1-attributes","title":"Attributes - DaisyUIComponents.Navbar.navbar/1","type":"function"},{"doc":"* `inner_block`","ref":"DaisyUIComponents.Navbar.html#navbar/1-slots","title":"Slots - DaisyUIComponents.Navbar.navbar/1","type":"function"},{"doc":"","ref":"DaisyUIComponents.Navbar.html#navbar_center/1","title":"DaisyUIComponents.Navbar.navbar_center/1","type":"function"},{"doc":"* Global attributes are accepted.","ref":"DaisyUIComponents.Navbar.html#navbar_center/1-attributes","title":"Attributes - DaisyUIComponents.Navbar.navbar_center/1","type":"function"},{"doc":"* `inner_block`","ref":"DaisyUIComponents.Navbar.html#navbar_center/1-slots","title":"Slots - DaisyUIComponents.Navbar.navbar_center/1","type":"function"},{"doc":"","ref":"DaisyUIComponents.Navbar.html#navbar_end/1","title":"DaisyUIComponents.Navbar.navbar_end/1","type":"function"},{"doc":"* Global attributes are accepted.","ref":"DaisyUIComponents.Navbar.html#navbar_end/1-attributes","title":"Attributes - DaisyUIComponents.Navbar.navbar_end/1","type":"function"},{"doc":"* `inner_block`","ref":"DaisyUIComponents.Navbar.html#navbar_end/1-slots","title":"Slots - DaisyUIComponents.Navbar.navbar_end/1","type":"function"},{"doc":"","ref":"DaisyUIComponents.Navbar.html#navbar_start/1","title":"DaisyUIComponents.Navbar.navbar_start/1","type":"function"},{"doc":"* Global attributes are accepted.","ref":"DaisyUIComponents.Navbar.html#navbar_start/1-attributes","title":"Attributes - DaisyUIComponents.Navbar.navbar_start/1","type":"function"},{"doc":"* `inner_block`","ref":"DaisyUIComponents.Navbar.html#navbar_start/1-slots","title":"Slots - DaisyUIComponents.Navbar.navbar_start/1","type":"function"},{"doc":"Button Group component\n\nhttps://daisyui.com/components/pagination/","ref":"DaisyUIComponents.Pagination.html","title":"DaisyUIComponents.Pagination","type":"module"},{"doc":"","ref":"DaisyUIComponents.Pagination.html#calculate_display_btn/3","title":"DaisyUIComponents.Pagination.calculate_display_btn/3","type":"function"},{"doc":"Renders a button group.","ref":"DaisyUIComponents.Pagination.html#pagination/1","title":"DaisyUIComponents.Pagination.pagination/1","type":"function"},{"doc":"<.pagination page={1} page_size={10} total_entries={100} />","ref":"DaisyUIComponents.Pagination.html#pagination/1-examples","title":"Examples - DaisyUIComponents.Pagination.pagination/1","type":"function"},{"doc":"* `page` (`:integer`) - Defaults to `1`.\n* `page_size` (`:integer`) - Defaults to `10`.\n* `total_entries` (`:integer`) - Defaults to `100`.\n* `button_class` (`:string`) - Defaults to `nil`.\n* `target` (`:string`) - Defaults to `nil`.\n* `page_click_event` (`:string`) - Defaults to `\"page_click\"`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Pagination.html#pagination/1-attributes","title":"Attributes - DaisyUIComponents.Pagination.pagination/1","type":"function"},{"doc":"Select component\n\nhttps://daisyui.com/components/select","ref":"DaisyUIComponents.Select.html","title":"DaisyUIComponents.Select","type":"module"},{"doc":"","ref":"DaisyUIComponents.Select.html#select/1","title":"DaisyUIComponents.Select.select/1","type":"function"},{"doc":"* `color` (`:string`) - Must be one of `\"primary\"`, `\"secondary\"`, `\"accent\"`, `\"info\"`, `\"success\"`, `\"warning\"`, or `\"error\"`.\n* `bordered` (`:boolean`) - Defaults to `false`.\n* `ghost` (`:boolean`) - Defaults to `false`.\n* `size` (`:string`) - Must be one of `\"xs\"`, `\"sm\"`, `\"md\"`, or `\"lg\"`.\n* `value` (`:any`) - Defaults to `nil`.\n* Global attributes are accepted. Supports all globals plus: `[\"name\", \"value\", \"multiple\"]`.","ref":"DaisyUIComponents.Select.html#select/1-attributes","title":"Attributes - DaisyUIComponents.Select.select/1","type":"function"},{"doc":"* `inner_block`","ref":"DaisyUIComponents.Select.html#select/1-slots","title":"Slots - DaisyUIComponents.Select.select/1","type":"function"},{"doc":"Stat component\n\nhttps://daisyui.com/components/stat","ref":"DaisyUIComponents.Stat.html","title":"DaisyUIComponents.Stat","type":"module"},{"doc":"","ref":"DaisyUIComponents.Stat.html#stat/1","title":"DaisyUIComponents.Stat.stat/1","type":"function"},{"doc":"* `class` (`:string`) - Defaults to `nil`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Stat.html#stat/1-attributes","title":"Attributes - DaisyUIComponents.Stat.stat/1","type":"function"},{"doc":"* `inner_block`","ref":"DaisyUIComponents.Stat.html#stat/1-slots","title":"Slots - DaisyUIComponents.Stat.stat/1","type":"function"},{"doc":"","ref":"DaisyUIComponents.Stat.html#stat_actions/1","title":"DaisyUIComponents.Stat.stat_actions/1","type":"function"},{"doc":"* `class` (`:string`) - Defaults to `nil`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Stat.html#stat_actions/1-attributes","title":"Attributes - DaisyUIComponents.Stat.stat_actions/1","type":"function"},{"doc":"* `inner_block`","ref":"DaisyUIComponents.Stat.html#stat_actions/1-slots","title":"Slots - DaisyUIComponents.Stat.stat_actions/1","type":"function"},{"doc":"","ref":"DaisyUIComponents.Stat.html#stat_desc/1","title":"DaisyUIComponents.Stat.stat_desc/1","type":"function"},{"doc":"* `class` (`:string`) - Defaults to `nil`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Stat.html#stat_desc/1-attributes","title":"Attributes - DaisyUIComponents.Stat.stat_desc/1","type":"function"},{"doc":"* `inner_block`","ref":"DaisyUIComponents.Stat.html#stat_desc/1-slots","title":"Slots - DaisyUIComponents.Stat.stat_desc/1","type":"function"},{"doc":"","ref":"DaisyUIComponents.Stat.html#stat_figure/1","title":"DaisyUIComponents.Stat.stat_figure/1","type":"function"},{"doc":"* `class` (`:string`) - Defaults to `nil`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Stat.html#stat_figure/1-attributes","title":"Attributes - DaisyUIComponents.Stat.stat_figure/1","type":"function"},{"doc":"* `inner_block`","ref":"DaisyUIComponents.Stat.html#stat_figure/1-slots","title":"Slots - DaisyUIComponents.Stat.stat_figure/1","type":"function"},{"doc":"","ref":"DaisyUIComponents.Stat.html#stat_title/1","title":"DaisyUIComponents.Stat.stat_title/1","type":"function"},{"doc":"* `class` (`:string`) - Defaults to `nil`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Stat.html#stat_title/1-attributes","title":"Attributes - DaisyUIComponents.Stat.stat_title/1","type":"function"},{"doc":"* `inner_block`","ref":"DaisyUIComponents.Stat.html#stat_title/1-slots","title":"Slots - DaisyUIComponents.Stat.stat_title/1","type":"function"},{"doc":"","ref":"DaisyUIComponents.Stat.html#stat_value/1","title":"DaisyUIComponents.Stat.stat_value/1","type":"function"},{"doc":"* `class` (`:string`) - Defaults to `nil`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Stat.html#stat_value/1-attributes","title":"Attributes - DaisyUIComponents.Stat.stat_value/1","type":"function"},{"doc":"* `inner_block`","ref":"DaisyUIComponents.Stat.html#stat_value/1-slots","title":"Slots - DaisyUIComponents.Stat.stat_value/1","type":"function"},{"doc":"","ref":"DaisyUIComponents.Stat.html#stats/1","title":"DaisyUIComponents.Stat.stats/1","type":"function"},{"doc":"* `class` (`:string`) - Defaults to `nil`.\n* `direction` (`:string`) - Must be one of `\"horizontal\"`, or `\"vertical\"`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Stat.html#stats/1-attributes","title":"Attributes - DaisyUIComponents.Stat.stats/1","type":"function"},{"doc":"* `inner_block`","ref":"DaisyUIComponents.Stat.html#stats/1-slots","title":"Slots - DaisyUIComponents.Stat.stats/1","type":"function"},{"doc":"Table component\n\nhttps://daisyui.com/components/table/","ref":"DaisyUIComponents.Table.html","title":"DaisyUIComponents.Table","type":"module"},{"doc":"Renders a table with generic styling.","ref":"DaisyUIComponents.Table.html#table/1","title":"DaisyUIComponents.Table.table/1","type":"function"},{"doc":"<.table id=\"users\" rows={@users}>\n      <:col :let={user} label=\"id\"><%= user.id %></:col>\n      <:col :let={user} label=\"username\"><%= user.username %></:col>\n    </.table>\n\nor declaring the table components\n\n  <.table id=\"users\">\n    <.thead>\n      <.tr>\n        <.th>id</.th>\n        <.th>username</.th>\n      </.tr>\n    </.thead>\n    <.tbody>\n      <.tr :for={user <- @users}>\n        <.td><%= user.id %></.td>\n        <.td><%= user.username %></.td>\n      </.tr>\n    </.tbody>\n  </.table>","ref":"DaisyUIComponents.Table.html#table/1-examples","title":"Examples - DaisyUIComponents.Table.table/1","type":"function"},{"doc":"* `id` (`:string`) - Defaults to `nil`.\n* `rows` (`:list`)\n* `row_id` (`:any`) - the function for generating the row id. Defaults to `nil`.\n* `row_click` (`:any`) - the function for handling phx-click on each row. Defaults to `nil`.\n* `row_item` (`:any`) - the function for mapping each row before calling the :col and :action slots. Defaults to `&Function.identity/1`.\n* `zebra` (`:boolean`) - Defaults to `false`.\n* `size` (`:string`) - Must be one of `\"xs\"`, `\"sm\"`, `\"md\"`, or `\"lg\"`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Table.html#table/1-attributes","title":"Attributes - DaisyUIComponents.Table.table/1","type":"function"},{"doc":"* `col` - Accepts attributes:\n\n  * `label` (`:string`)\n* `action` - the slot for showing user actions in the last table column.\n* `inner_block`","ref":"DaisyUIComponents.Table.html#table/1-slots","title":"Slots - DaisyUIComponents.Table.table/1","type":"function"},{"doc":"","ref":"DaisyUIComponents.Table.html#tbody/1","title":"DaisyUIComponents.Table.tbody/1","type":"function"},{"doc":"* Global attributes are accepted.","ref":"DaisyUIComponents.Table.html#tbody/1-attributes","title":"Attributes - DaisyUIComponents.Table.tbody/1","type":"function"},{"doc":"* `inner_block`","ref":"DaisyUIComponents.Table.html#tbody/1-slots","title":"Slots - DaisyUIComponents.Table.tbody/1","type":"function"},{"doc":"","ref":"DaisyUIComponents.Table.html#td/1","title":"DaisyUIComponents.Table.td/1","type":"function"},{"doc":"* Global attributes are accepted.","ref":"DaisyUIComponents.Table.html#td/1-attributes","title":"Attributes - DaisyUIComponents.Table.td/1","type":"function"},{"doc":"* `inner_block`","ref":"DaisyUIComponents.Table.html#td/1-slots","title":"Slots - DaisyUIComponents.Table.td/1","type":"function"},{"doc":"","ref":"DaisyUIComponents.Table.html#th/1","title":"DaisyUIComponents.Table.th/1","type":"function"},{"doc":"* Global attributes are accepted.","ref":"DaisyUIComponents.Table.html#th/1-attributes","title":"Attributes - DaisyUIComponents.Table.th/1","type":"function"},{"doc":"* `inner_block`","ref":"DaisyUIComponents.Table.html#th/1-slots","title":"Slots - DaisyUIComponents.Table.th/1","type":"function"},{"doc":"","ref":"DaisyUIComponents.Table.html#thead/1","title":"DaisyUIComponents.Table.thead/1","type":"function"},{"doc":"* Global attributes are accepted.","ref":"DaisyUIComponents.Table.html#thead/1-attributes","title":"Attributes - DaisyUIComponents.Table.thead/1","type":"function"},{"doc":"* `inner_block`","ref":"DaisyUIComponents.Table.html#thead/1-slots","title":"Slots - DaisyUIComponents.Table.thead/1","type":"function"},{"doc":"","ref":"DaisyUIComponents.Table.html#tr/1","title":"DaisyUIComponents.Table.tr/1","type":"function"},{"doc":"* `active` (`:boolean`) - Defaults to `false`.\n* `hover` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Table.html#tr/1-attributes","title":"Attributes - DaisyUIComponents.Table.tr/1","type":"function"},{"doc":"* `inner_block`","ref":"DaisyUIComponents.Table.html#tr/1-slots","title":"Slots - DaisyUIComponents.Table.tr/1","type":"function"},{"doc":"TextInput component\n\nhttps://daisyui.com/components/input","ref":"DaisyUIComponents.TextInput.html","title":"DaisyUIComponents.TextInput","type":"module"},{"doc":"","ref":"DaisyUIComponents.TextInput.html#text_input/1","title":"DaisyUIComponents.TextInput.text_input/1","type":"function"},{"doc":"* `type` (`:string`) - Defaults to `\"text\"`.\n* `color` (`:string`) - Must be one of `\"primary\"`, `\"secondary\"`, `\"accent\"`, `\"info\"`, `\"success\"`, `\"warning\"`, or `\"error\"`.\n* `bordered` (`:boolean`) - Defaults to `false`.\n* `ghost` (`:boolean`) - Defaults to `false`.\n* `size` (`:string`) - Must be one of `\"xs\"`, `\"sm\"`, `\"md\"`, or `\"lg\"`.\n* Global attributes are accepted. Supports all globals plus: `[\"name\", \"value\"]`.","ref":"DaisyUIComponents.TextInput.html#text_input/1-attributes","title":"Attributes - DaisyUIComponents.TextInput.text_input/1","type":"function"},{"doc":"Textarea component\n\nhttps://daisyui.com/components/textarea","ref":"DaisyUIComponents.Textarea.html","title":"DaisyUIComponents.Textarea","type":"module"},{"doc":"","ref":"DaisyUIComponents.Textarea.html#textarea/1","title":"DaisyUIComponents.Textarea.textarea/1","type":"function"},{"doc":"* `value` (`:any`) - Defaults to `nil`.\n* `color` (`:string`) - Must be one of `\"primary\"`, `\"secondary\"`, `\"accent\"`, `\"info\"`, `\"success\"`, `\"warning\"`, or `\"error\"`.\n* `bordered` (`:boolean`) - Defaults to `false`.\n* `ghost` (`:boolean`) - Defaults to `false`.\n* `size` (`:string`) - Must be one of `\"xs\"`, `\"sm\"`, `\"md\"`, or `\"lg\"`.\n* Global attributes are accepted. Supports all globals plus: `[\"name\"]`.","ref":"DaisyUIComponents.Textarea.html#textarea/1-attributes","title":"Attributes - DaisyUIComponents.Textarea.textarea/1","type":"function"},{"doc":"* `inner_block`","ref":"DaisyUIComponents.Textarea.html#textarea/1-slots","title":"Slots - DaisyUIComponents.Textarea.textarea/1","type":"function"},{"doc":"Tooltip component\n\nhttps://daisyui.com/components/tooltip","ref":"DaisyUIComponents.Tooltip.html","title":"DaisyUIComponents.Tooltip","type":"module"},{"doc":"","ref":"DaisyUIComponents.Tooltip.html#tooltip/1","title":"DaisyUIComponents.Tooltip.tooltip/1","type":"function"},{"doc":"* `text` (`:string`) (required)\n* `color` (`:string`) - Must be one of `\"primary\"`, `\"secondary\"`, `\"accent\"`, `\"info\"`, `\"success\"`, `\"warning\"`, or `\"error\"`.\n* `direction` (`:string`) - Must be one of `\"left\"`, `\"top\"`, `\"right\"`, or `\"bottom\"`.\n* `open` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted.","ref":"DaisyUIComponents.Tooltip.html#tooltip/1-attributes","title":"Attributes - DaisyUIComponents.Tooltip.tooltip/1","type":"function"},{"doc":"* `inner_block`","ref":"DaisyUIComponents.Tooltip.html#tooltip/1-slots","title":"Slots - DaisyUIComponents.Tooltip.tooltip/1","type":"function"}],"producer":{"name":"ex_doc","version":[48,46,51,50,46,49]}}